@@ -2,8 +2,10 @@ from .generate_annofile import *
 from .modify import *
 from .parse import *
 from .check import *
+from .visualization import *
 
 __all__ = ['generate_annofile',
            'parse_label', 'parse_txt',
            'modify_annoroot', 'modify_annocls', 'modify_label',
-           'print_label', 'check_bboxlabel']
+           'print_label', 'check_bboxlabel',
+           'visualize_aug']
